@@ -1,11 +1,13 @@
+from django.contrib.auth import get_user_model
 from ninja import Schema
+from ninja.orm import create_schema
 from typing import Dict, List
 
 
-class UserOut(Schema):
-    id: int
-    username: str
-    email: str
+UserOut = create_schema(
+    get_user_model(),
+    exclude=['password']
+)
 
 
 class LoginIn(Schema):
